Crate kcr_infra_contrib_fluxcd_io

Crate kcr_infra_contrib_fluxcd_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the infra.contrib.fluxcd.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

infra.contrib.fluxcd.io/v1alpha1

  • Terraform

infra.contrib.fluxcd.io/v1alpha2

  • Terraform

Modules

v1alpha1
v1alpha2